@@ -1,6 +1,5 @@
 import time
 from abc import ABCMeta, abstractmethod
-from typing import Self
 
 
 class IRemote(metaclass=ABCMeta):
@@ -26,10 +25,16 @@ class IRemote(metaclass=ABCMeta):
     def identifier(self):
         pass
 
-    def apply(self, data: dict) -> Self:
+    def apply(self, data: dict):
+        def fget(attr, val):
+            if attr == "mode":
+                return (getattr(self, attr), val, 1)
+            return (self, attr, val)
+
         for attr, val in data.items():
             if hasattr(self, attr):
-                setattr(self, attr, val)
+                target, attr, val = fget(attr, val)
+                setattr(target, attr, val)
         return self
 
     def then_wait(self):
