@@ -3,10 +3,9 @@ from abc import abstractmethod
 from math import log
 from typing import Union
 
-from .error import VMError
 from .iremote import IRemote
 from .kinds import kinds_all
-from .meta import bool_prop
+from .meta import bool_prop, float_prop
 
 
 class Strip(IRemote):
@@ -82,6 +81,16 @@ class Strip(IRemote):
 
 
 class PhysicalStrip(Strip):
+    @classmethod
+    def make(cls, kind):
+        """
+        Factory method for PhysicalStrip.
+
+        Returns a PhysicalStrip class.
+        """
+        EFFECTS_cls = _make_effects_mixins[kind.name]
+        return type(f"PhysicalStrip", (cls, EFFECTS_cls), {})
+
     def __str__(self):
         return f"{type(self).__name__}{self.index}"
 
@@ -162,6 +171,8 @@ class VirtualStrip(Strip):
     def treble(self):
         return round(self.getter("EQGain3"), 1)
 
+    high = treble
+
     @treble.setter
     def treble(self, val: float):
         self.setter("EQGain3", val)
@@ -176,29 +187,26 @@ class VirtualStrip(Strip):
 class StripLevel(IRemote):
     def __init__(self, remote, index):
         super().__init__(remote, index)
-        phys_map = tuple((i, i + 2) for i in range(0, remote.kind.phys_in * 2, 2))
-        virt_map = tuple(
-            (i, i + 8)
-            for i in range(
-                remote.kind.phys_in * 2,
-                remote.kind.phys_in * 2 + remote.kind.virt_in * 8,
-                8,
-            )
-        )
-        self.level_map = phys_map + virt_map
-        self.range = self.level_map[self.index]
+        self.range = _make_strip_level_maps[remote.kind.name][self.index]
 
     def getter(self, mode):
-        """Returns a tuple of level values for the channel."""
+        """
+        Returns a tuple of level values for the channel.
 
-        def fget(i):
-            if self._remote.running and "strip_level" in self._remote.cache:
-                res = self._remote.cache["strip_level"][i]
-            else:
-                res = self._remote.get_level(mode, i)
-            return round(20 * log(res, 10), 1) if res > 0 else -200.0
+        If observables thread running and level updates are subscribed to, fetch values from cache
 
-        return tuple(fget(i) for i in range(*self.range))
+        Otherwise call CAPI func.
+        """
+
+        def fget(x):
+            return round(20 * log(x, 10), 1) if x > 0 else -200.0
+
+        if self._remote.running and self._remote.event.ldirty:
+            vals = self._remote.cache["strip_level"][self.range[0] : self.range[-1]]
+        else:
+            vals = [self._remote.get_level(mode, i) for i in range(*self.range)]
+
+        return tuple(fget(val) for val in vals)
 
     @property
     def identifier(self) -> str:
@@ -220,8 +228,32 @@ class StripLevel(IRemote):
         return self.getter(2)
 
     @property
-    def is_updated(self) -> bool:
-        return any(self._remote._strip_comp[self.range[0] : self.range[-1]])
+    def isdirty(self) -> bool:
+        """
+        Returns dirty status for this specific channel.
+
+        Expected to be used in a callback only.
+        """
+        if self._remote.running:
+            return any(self._remote._strip_comp[self.range[0] : self.range[-1]])
+
+    is_updated = isdirty
+
+
+def make_strip_level_map(kind):
+    phys_map = tuple((i, i + 2) for i in range(0, kind.phys_in * 2, 2))
+    virt_map = tuple(
+        (i, i + 8)
+        for i in range(
+            kind.phys_in * 2,
+            kind.phys_in * 2 + kind.virt_in * 8,
+            8,
+        )
+    )
+    return phys_map + virt_map
+
+
+_make_strip_level_maps = {kind.name: make_strip_level_map(kind) for kind in kinds_all}
 
 
 class GainLayer(IRemote):
@@ -272,6 +304,52 @@ _make_channelout_mixins = {
 }
 
 
+def _make_effects_mixin(kind):
+    """creates an effects mixin for a kind"""
+    XY_cls = type(
+        "XY",
+        (),
+        {
+            param: float_prop(param)
+            for param in [
+                "pan_x",
+                "pan_y",
+                "color_x",
+                "color_y",
+                "fx_x",
+                "fx_y",
+            ]
+        },
+    )
+
+    FX_cls = type(
+        "FX",
+        (),
+        {
+            **{
+                param: float_prop(param)
+                for param in [
+                    "reverb",
+                    "delay",
+                    "fx1",
+                    "fx2",
+                ]
+            },
+            **{
+                f"post{param}": bool_prop(f"post{param}")
+                for param in ["reverb", "delay", "fx1", "fx2"]
+            },
+        },
+    )
+
+    if kind.name == "potato":
+        return type(f"Effects{kind}", (XY_cls, FX_cls), {})
+    return type(f"Effects{kind}", (XY_cls,), {})
+
+
+_make_effects_mixins = {kind.name: _make_effects_mixin(kind) for kind in kinds_all}
+
+
 def strip_factory(is_phys_strip, remote, i) -> Union[PhysicalStrip, VirtualStrip]:
     """
     Factory method for strips
@@ -280,7 +358,7 @@ def strip_factory(is_phys_strip, remote, i) -> Union[PhysicalStrip, VirtualStrip
 
     Returns a physical or virtual strip subclass
     """
-    STRIP_cls = PhysicalStrip if is_phys_strip else VirtualStrip
+    STRIP_cls = PhysicalStrip.make(remote.kind) if is_phys_strip else VirtualStrip
     CHANNELOUTMIXIN_cls = _make_channelout_mixins[remote.kind.name]
 
     _kls = (STRIP_cls, CHANNELOUTMIXIN_cls)
