@@ -1,4 +1,6 @@
 import functools
+from itertools import zip_longest
+from typing import Iterator
 
 
 def polling(func):
@@ -50,3 +52,21 @@ def script(func):
         return func(remote, script)
 
     return wrapper
+
+
+def comp(t0: tuple, t1: tuple) -> Iterator[bool]:
+    """
+    Generator function, accepts two tuples.
+
+    Evaluates equality of each member in both tuples.
+    """
+    for a, b in zip(t0, t1):
+        yield a == b
+
+
+def grouper(n, iterable, fillvalue=None):
+    """
+    Group elements of an iterable by sets of n length
+    """
+    args = [iter(iterable)] * n
+    return zip_longest(fillvalue=fillvalue, *args)
